#
# spec file for package fstl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fstl
Version:        0.11.0
Release:        1.1
Summary:        Fast stl file viewer
License:        AGPL-3.0-only
Group:          Productivity/Graphics/3D Editors
URL:            https://github.com/mkeeter/fstl.git
Source0:        https://github.com/fstl-app/fstl/archive/refs/tags/v%{version}.tar.gz
Source1:        %{name}.desktop
BuildRequires:  cmake >= 2.8.12
BuildRequires:  hicolor-icon-theme
BuildRequires:  icoutils
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)

%description
Fast stl file viewer.
It is designed to quickly load and render very high-polygon models; showing 2 million triangles at 60+ FPS on a mid-range laptop.

%prep
%setup -q

%build
CFLAGS="%{optflags}"
export CFLAGS
%cmake
%make_build

%install
%cmake_install
cd exe
icotool -x fstl.ico
install -Dm 0755 fstl_1_16x16x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
install -Dm 0755 fstl_2_32x32x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -Dm 0755 fstl_3_48x48x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -Dm 0755 fstl_4_64x64x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -Dm 0755 fstl_5_128x128x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -Dm 0755 fstl_6_256x256x32.png \
  %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

%suse_update_desktop_file -i %{name}

%files
%{_bindir}/fstl
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.11.0:
  * Updates from 0.10.0 release #85
  * Fix STL file selection filter #92
  * Add arc-ball mechanism to mouse control #99
  * Set application icon, so it will appear in about window and in dock f… #100
  * Add the option to reset or not the rotation when loading a new stl file. #103
  * Add fullscreen option in View menu associated with key F11 #104
  * wait to load the stl file until file size does not change anymore #106
  * Clean commit c4dd685 #108
  * Wait for the STL file size to stop changing. #107
  * Revert "wait to load the stl file until file size does not change anymore (#106)
  * Will dev customizable shader #102
  * Common Viewpoints #110
  * Support standard Close shortcut #115
  * Add xdg directory for linux desktop file and app icons. #101
  * Add Viewpoint shortcuts and isometric view #118
  * Minor fix, update version and copyright years #125
  * Feature/open external #126
* Sun Jul 24 2022 Mike Chikov <mike.chikov@gmail.com>
- Remove fstl-mimeinfo.xml
- Modify fstl.desktop
* Thu Jul 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * Added README section for setting fstl as default viewer #52
  * Fix initial settings #54
  * Show 3D axes in viewer #55
  * Allow uppercase file suffixes as well #60
  * Implement an Invert Zoom option #61
  * Remove Legacy Qt Build Option scholl in #62
  * Added "Surface Angle" draw mode based on github stl viewer #66
  * Versioning in app, other small changes #64
  * Fix several Qt deprecation warnings #67
  * Remember application settings #78
  * Implement compact and fullscreen view #81
* Thu Jul 21 2022 Michael Vetter <mvetter@suse.com>
- Copy version 0.9.4 from home:mrbadguy/fstl
- Run spec-cleaner
- Remove camera-pos.patch
- Remove _service and use regular tarball
- Remove calls to %%mime_database_post, %%desktop_database_post,
  %%icon_theme_cache_post since since they are run via rpm file
  triggers now
